@@ -1,17 +1,25 @@
-use Cwd;
-my $cwd = cwd;
+use Cwd ();
+my($cwd,$rcwd);
 my $Iswin = $^O eq "MSWin32";
+if ($Iswin) {
+  $cwd = Cwd::getdcwd();
+  $rcwd = Cwd::realpath($cwd);
+} else {
+  $cwd = $rcwd = Cwd::cwd();
+}
 $CPAN::Config = {
                  $Iswin ? () : (
                                 'make_install_make_command' => q[make],
                                 'mbuild_install_build_command' => q[./Build],
                                ),
                  '7yYQS7' => 'vGcVJQ', # verifies that we really loaded this file
+                 'allow_installing_module_downgrades' => 'yes',
+                 'allow_installing_outdated_dists' => 'yes',
                  'auto_commit' => 0,
                  'build_cache' => q[100],
                  'build_dir' => qq[$cwd/t/dot-cpan/build],
                  #'bzip2' => q[/bin/bzip2],
-                 'cache_metadata' => q[1],
+                 'cache_metadata' => q[0],
                  colorize_output=>0,
                  'cpan_home' => qq[$cwd/t/dot-cpan],
                  #'curl' => q[],
@@ -28,6 +36,7 @@ $CPAN::Config = {
                  'inhibit_startup_message' => q[0],
                  'keep_source_where' => qq[$cwd/t/dot-cpan/sources],
                  #'lynx' => q[],
+                 'load_module_verbosity' => q[v],
                  #'make' => q[/usr/bin/make],
                  'make_arg' => q[],
                  'make_install_arg' => q[UNINST=1],
@@ -48,7 +57,7 @@ $CPAN::Config = {
                  'term_is_latin' => q[0],
                  'term_ornaments' => q[0],
                  #'unzip' => q[/usr/bin/unzip],
-                 'urllist' => [qq[file://$cwd/t/CPAN]],
+                 'urllist' => [qq[file://$rcwd/t/CPAN]],
                  'wait_list' => [q[wait://ls6.informatik.uni-dortmund.de:1404]],
                  #'wget' => q[/usr/bin/wget],
                  'yaml_load_code' => q[0],
